'use strict';

import React, {Component} from 'react';
import PropTypes from 'prop-types';
import {Platform, View, Dimensions, Text} from 'react-native';
import {BasePage, KeyboardSpace, NavigationBar, Theme, TeaNavigator} from "teaset";
import CustomBasePage from "./CustomBasePage";
import { hairWidth } from '../utils'
import { Color } from 'chalk';


export default class CustomPage extends CustomBasePage {

    static propTypes = {
        ...BasePage.propTypes,
        title: PropTypes.string,
        backgroundColor: PropTypes.string,
        tintColor: PropTypes.string,
        titleStyle: Text.propTypes.style,
        showBackButton: PropTypes.bool,
        navigationBarInsets: PropTypes.bool,
    };

    static defaultProps = {
        ...BasePage.defaultProps,
        scene: TeaNavigator.SceneConfigs.PushFromRight,
        title: null,
        backgroundColor: 'transparent',
        tintColor: '#FFFFFF',
        titleStyle: null,
        showBackButton: false,
        navigationBarInsets: true,
    };

    constructor(props) {
        super(props);
        this.screenWidth = Dimensions.get('window').width;
    }

    setTitle(title){
        this.setState({title});
    }
    
    onLayout(e) {
        let {width} = Dimensions.get('window');
        if (width != this.screenWidth) {
            this.screenWidth = width;
            this.forceUpdate();
        }
        this.props.onLayout && this.props.onLayout(e);
    }

    renderNavigationTitle() {
        return this.state.title || this.props.title;
    }

    renderNavigationLeftView() {
        if (!this.props.showBackButton) return null;
        return (
            <NavigationBar.BackButton
                title={this.props.hasOwnProperty('backButtonTitle') ? this.props.backButtonTitle : Theme.backButtonTitle}
                onPress={() => {
                    this.onBackPress ? this.onBackPress() : this.navigator.pop()
                }}
            />
        );
    }

    renderNavigationRightView() {
        return null;
    }

    renderNavigationBar() {
        return (
            <NavigationBar
                tintColor={this.props.tintColor}
                backgroundColor={this.props.backgroundColor}
                titleStyle={this.props.titleStyle}
                title={this.renderNavigationTitle()}
                leftView={this.renderNavigationLeftView()}
                rightView={this.renderNavigationRightView()}
            />
        );
    }

    renderPage() {
        return null;
    }

    render() {
        let {style, children, scene, autoKeyboardInsets, keyboardTopInsets, title, showBackButton, navigationBarInsets, ...others} = this.props;

        let {left: paddingLeft, right: paddingRight} = Theme.screenInset;
        let pageContainerStyle = [{
            flex: 1,
            paddingLeft,
            paddingRight,
            marginTop: navigationBarInsets ? (Theme.navBarContentHeight + Theme.statusBarHeight) : 0,
        }];

        return (
            <View style={this.buildStyle()} onLayout={e => this.onLayout(e)} {...others}>
                <View style={{flex: 1}}>
                    <View style={pageContainerStyle}>
                        {this.renderPage()}
                    </View>
                    {this.renderNavigationBar()}
                </View>
                {autoKeyboardInsets ? <KeyboardSpace topInsets={keyboardTopInsets}/> : null}
            </View>
        );
    }


}


