/*
 * @Author: Hinjin
 * @Date: 2020-03-15 19:48:49
 * @LastEditors: Hinjin
 * @LastEditTime: 2020-09-01 22:56:26
 * @FilePath: src/utils/request.js
 */
import Constants from "./Constants";
import axios from 'axios';
import { Platform, AsyncStorage } from "react-native";
import StorageUtil from "./StorageUtil";
import CommonUtil from "./CommonUtil";

axios.defaults.baseURL = Constants.GET_BASE_URL();
axios.defaults.headers.post['Content-Type'] = 'application/json';
axios.defaults.headers.common['source'] = Platform.OS === "ios" ? 'app-ios' : 'app-android';

let isGetHost = false;
const request = async ({ url, method = 'GET', params, data, headers }) => {
  const token = await StorageUtil.getString(Constants.KEY_TOEKN);
  if (!window.host && !isGetHost) {
    window.host = await StorageUtil.getString('host');
    axios.defaults.baseURL = Constants.GET_BASE_URL();
    isGetHost = true;
  }
  axios.defaults.headers.common['Authorization'] = token;
  if (!!headers && headers['Content-Type']) {
    axios.defaults.headers.post['Content-Type'] = headers['Content-Type'];
  };
  const _headers = {
    ...headers,
    Authorization: token
  }
  return axios({
    method,
    url,
    params,
    data,
    headers: _headers,
    // headers: {
    //   // 'Content-Type': 'multipart/form-data;',
    //   Authorization: token
    // }
  });
}

// 响应拦截器
axios.interceptors.response.use(res => {
  const code = res.data.code;
  // 登录失效
  if (code === 99998) {
    CommonUtil.logOut();
    return res.data.data;
  } else if (code !== 0) {
    return Promise.reject(res.data.msg)
  } else {
    return res.data.data;
  }
},
  error => {
    console.log('err' + error)
    return Promise.reject(error)
  }
)


export default request;